########################  Custom functions ###############################
# This file contains all custom functions and otherwise needed for data
# analysis

### Custom Functions ###
# Set a theme for VennDiagrams
myCol <- brewer.pal(3, "Pastel2")



################################ Functions #################################### 
repeatability <- function(file){
  dat <- read_tsv(file = file, skip = 0, col_names = T,col_types = cols())
  
  # Create data matrix and set variables to 1
  matrix <- tibble()
  column_names <- c()
  i <- 1
  j <- 1
  
  for (k in 1:((ncol(dat)/2))) {
    matrix[j, 1] <- overlap(dat, i) / total(dat, i) * 100
    
    column_names <- c(column_names, colnames(dat[i]))
    j <- j+1
    i <- i+2
    
  }
  
  data <- cbind(column_names, matrix)
  colnames(data) <- c("method", "Percentage")
  return(data)
}

overlap <- function(dat, i){
  as.numeric(dat %>%
               filter(dat[i] == "+" & dat[i+1] == "+") %>%
               summarise(sum(Count)))
}

total <- function(dat, i){
  as.numeric(dat %>%
               filter(dat[i] == "+" | dat[i+1] == "+") %>%
               summarise(sum(Count)))
}

# Combine two TEM images into one
combineTEM <- function(path1, path2, isolation){
  # Image 1
  img1 <- image_read(path1)
  
  # Image 2  
  img2 <- image_read(path2)
  
  # Combine
  imgCom <- c(img1, img2)
  imgCom <- image_append(imgCom)
  
  # Add border
  imgCom <- image_border(imgCom, "white", "20x0")
  
  # Add text
  imgCom <- image_annotate(imgCom, text = isolation, font = 'ArialMT', size = 100, location = "+50+20")
  
  # Save file
  image_write(imgCom, path = paste("Figures/1 - Optimization study (2016)/Edited/TEM/Combined/", isolation, ".png", sep = ""), format = "png")
  
  # Return function
  filename <- paste(isolation, "_TEM", sep = "")
  filename <- image_append(image_scale(imgCom))
  return(filename)
  
}

# Crop TEM images
TEMimgCrop <- function(input, name){
  ## Crop image
  img <- image_read(input)
  crop <- image_crop(img, "800x800+200+100")
  
  ## Add scalebar
  img <- image_composite(crop, image_read("Figures/1 - Optimization study (2016)/Raw/TEM/scale_bar.png"), offset =  "+475+700")
  
  ## Save image
  image_write(img, path = paste("Figures/1 - Optimization study (2016)/Edited/TEM/Cropped/", name, sep = ""), format = "png")
  
}

# Check significance level
sig_test <- function(file){
  dat <- read_tsv(file = file, skip = 3, col_names = F, col_types = cols()) 
  colnames(dat) <- colnames(read_tsv(file = file, col_types = cols()))

  
  pvalues <- dat %>%
    select(contains(("q-value ")))
  
  
  # Create empty list
  pval <- c()
  
  # Loop that goes over all samples and checks IDs

    pval <- c(pval, c(checkP(pvalues[1])))
    pval <- c(pval, c(checkP(pvalues[3])))
    pval <- c(pval, c(checkP(pvalues[2])))
  
  return(pval)
  
}
# Check significance level alt
sig_test_alt <- function(file){
  dat <- read_tsv(file = file, skip = 3, col_names = F, col_types = cols()) 
  colnames(dat) <- colnames(read_tsv(file = file, col_types = cols()))
  
  
  pvalues <- dat %>%
    select(contains(("q-value ")))
  
  
  # Create empty list
  pval <- c()
  
  # Loop that goes over all samples and checks IDs
  for(i in 1:3){
    pval <- c(pval, c(checkPalt(pvalues[i])))
  }
  
  return(pval)
  
}



# Provides q value and stars
ms_inference <- function (file){
  dat <- read_tsv(file = file, skip = 3, col_names = F,col_types = cols())
  colnames(dat) <- colnames(read_tsv(file = file,col_types = cols()))
  
  dat <- dat %>%
    select(contains(("q-value "))) %>%
    t()
  
  
  # Create stars
  dat <- cbind(dat,sig_test_alt(file))
  
  colnames(dat) <- c("q-value", "Stars")
  
  return(dat)
}
## Function that extracts names to use in correlation matrix
createNamesCorrelation <- function(df){
  
  # Internal functions
  check <- function(df, pattern) {
    df %>%
      str_detect(pattern)
  }
  cextract <- function(df){
    df %>%
      str_sub(start = 12L, end =12L)
  }
  
  
  # Define stuff
  names <- c()
  j <- 1
  
  # For loop
  for (i in 1:(nrow(df)/17)) {
    # Checks for isolation method
    if (check(df[j, 1], "UC")){ # Cent.
      names <- c(names, paste("Cent. (Con.", extract(df[j,1]), ")", sep = ""))
    } else if (check(df[j,1], "SEC")) { # SEC
      names <- c(names, paste("SEC (Con.", extract(df[j,1]), ")", sep = ""))
    } else if (check(df[j, 1], "VN96")) { # PAP
      names <- c(names, paste("PAP (Con.", extract(df[j,1]), ")", sep = ""))
    }
    j <- j + 17
  }
  return(names)
  
}
## Function that extracts names to use in correlation matrix
changeNamesRow <- function(df){
  
  # Internal functions
  check <- function(df, pattern) {
    df %>%
      str_detect(pattern)
  }
  cextract <- function(df){
    df %>%
      str_sub(start = 12L, end =12L)
  }
  
  
  # Define stuff
  names <- c()
  j <- 1
  
  # For loop
  for (i in 1:(nrow(df))) {
    # Checks for isolation method
    if (check(df[i, 1], "UC")){ # Cent.
      names <- c(names, paste("Cent. (Con.", extract(df[i,1]), ")", sep = ""))
    } else if (check(df[i,1], "SEC")) { # SEC
      names <- c(names, paste("SEC (Con.", extract(df[i,1]), ")", sep = ""))
    } else if (check(df[i, 1], "VN96")) { # PAP
      names <- c(names, paste("PAP (Con.", extract(df[i,1]), ")", sep = ""))
    }
  }
  return(names)
  
}
## Function to move column (https://stackoverflow.com/questions/3369959/moving-columns-within-a-data-frame-without-retyping/18540144#18540144)
moveme <- function (invec, movecommand) {
  movecommand <- lapply(strsplit(strsplit(movecommand, ";")[[1]], 
                                 ",|\\s+"), function(x) x[x != ""])
  movelist <- lapply(movecommand, function(x) {
    Where <- x[which(x %in% c("before", "after", "first", 
                              "last")):length(x)]
    ToMove <- setdiff(x, Where)
    list(ToMove, Where)
  })
  myVec <- invec
  for (i in seq_along(movelist)) {
    temp <- setdiff(myVec, movelist[[i]][[1]])
    A <- movelist[[i]][[2]][1]
    if (A %in% c("before", "after")) {
      ba <- movelist[[i]][[2]][2]
      if (A == "before") {
        after <- match(ba, temp) - 1
      }
      else if (A == "after") {
        after <- match(ba, temp)
      }
    }
    else if (A == "first") {
      after <- 0
    }
    else if (A == "last") {
      after <- length(myVec)
    }
    myVec <- append(temp, values = movelist[[i]][[1]], after = after)
  }
  myVec
}
# Error bars MS data
errorBar <- function(dat){
  dat <- read_tsv(file = dat, skip = 3, col_names = F, col_types = cols())
  col1 <- c("Cent.", "SEC", "PAP")
  col2 <- c(rowMeans(dat[1:3], na.rm = T), # Cent.
            rowMeans(dat[4:6], na.rm = T), # SEC
            rowMeans(dat[7:9], na.rm = T)) # PAP)
  col3 <- c(rowSds(as.matrix(dat[1:3]), na.rm = T), # Cent.
            rowSds(as.matrix(dat[4:6]), na.rm = T), # SEC
            rowSds(as.matrix(dat[7:9]),na.rm = T)) # PAP
  
  df <- data.frame(col1, col3, col2, stringsAsFactors=FALSE) 
  colnames(df) <- c("method","sd", "riBAQ")
  
  return(df)
}

# Read MS data
readMS <- function(file){
  dat <- read_tsv(file = file, skip = 2, col_names = F, col_types = cols()) %>% 
    select(1:9) %>%
    t() %>%
    as.data.frame
  
  # Change riBAQ to numeric
  dat$V2 <- as.numeric(as.character(dat$V2))
  
  # Set new names
  colnames(dat) <- c("method", "riBAQ") # set column names
  dat[1]<- c("Cent.", "Cent.", "Cent.", "SEC", "SEC", "SEC", "PAP", "PAP", "PAP")
  
return(as_tibble(dat))
}

# Check P
checkP <- function(dat){
  if(dat<0.001){
    return("***")
  } 
  else if(dat < 0.01){
    return("**")
  }
  else if(dat < 0.05){
    return("*")
  }
}

checkPalt <- function(dat){
  if(dat<0.001){
    return("***")
  } 
  else if(dat < 0.01){
    return("**")
  }
  else if(dat < 0.05){
    return("*")
  }
  else{
    return("ns")
  }
}

sig_lines(alb_df)
sig_test(totEV_df)
sig_lines(lip_df)

# Draw signif lines for MS data
sig_lines <- function (file){
  dat <- read_tsv(file = file, skip = 3, col_names = F,col_types = cols())
  colnames(dat) <- colnames(read_tsv(file = file,col_types = cols()))
  
  pvalues <- dat %>%
    select(contains(("q-value ")))
  
  # Create empty list
  list <- list()
  CENTSEC <- F
  PAPCENT <- F
  SECPAP <- F
  
  # Loop that goes over all samples and checks IDs
  for(i in 1:3){
    if(pvalues[i] < 0.05){
      if(i == 1){
        list <- c(list, list(c("Cent.", "SEC")))
        CENTSEC <- T
      }
      else if(i == 2){
        list <- c(list, list(c("Cent.", "PAP")))
        PAPCENT <- T
      }
      else if(i ==3){
        list <- c(list, list(c("SEC", "PAP")))
        SECPAP <- T
      }
    }
  }
  
  if(CENTSEC & PAPCENT & SECPAP){
    data <- list(list[[1]], list[[3]], list[[2]])
  }
  else if(CENTSEC & PAPCENT){
    data <- list(list[[1]], list[[2]])
  }
  else{
    data <- list
  }
  return(data)
}


# Shorten scientific notations
scientific <- function(x)
{
  ifelse(x==0, "0", parse(text=gsub("[+]", "", gsub("e", " %*% 10^", scientific_format()(x)))))
}


# Replace , with . and set to numeric
toNumeric <- function(dat, columNr){
  for (i in 1:columNr){
    dat[[2+i]] <- gsub("\\,", ".", dat[[2+i]])
    dat[[2+i]] <- as.numeric(dat[[2+i]])
  }
  return(dat)
  
}


vennDiagramMatrix <- function(file){
  dat <- read_tsv(file = file, skip = 0, col_names = T,col_types = cols())
  
  # Create data matrix
  matrix <- matrix()
  
  # Find all UC (Area 1)
  matrix <- dat %>%
    filter(dat$UC == "+") %>%
    summarise("Area 1 (Cent.)" = sum(Count))
  
  # Find all SEC (Area 2)
  matrix[2] <- dat %>%
    filter(dat$SEC == "+") %>%
    summarise("Area 2 (SEC)" = sum(Count))
  
  # Find all PAP (area 3)
  matrix[3] <- dat %>%
    filter(dat$PAP == "+") %>%
    summarise("Area 3 (PAP)" = sum(Count))
  
  # Find UC and SEC (area 1+2)
  matrix[4] <- dat %>%
    filter(dat$UC == "+" & dat$SEC == "+") %>%
    summarise("Area 1+2 (Cent. + SEC)" = sum(Count))
  
  # Find SEC and PAP (area 2+3)
  matrix[5] <- dat %>%
    filter(dat$SEC == "+" & dat$PAP == "+") %>%
    summarise("Area 2+3 (SEC + PAP)" = sum(Count))
  
  # Find UC and PAP (area 1+3)
  matrix[6] <- dat %>%
    filter(dat$UC == "+" & dat$PAP == "+") %>%
    summarise("Area 1+3 (Cent. + PAP)" = sum(Count))
  
  # Find UC, SEC, and PAP (area 1+2+3)
  matrix[7] <- dat %>%
    filter(dat$UC == "+" & dat$PAP == "+" & dat$SEC == "+") %>%
    summarise("Area 1+2+3 (Cent. + SEC + PAP)" = sum(Count))
  
  return(as_tibble(matrix))
}

# Calculates fold change difference
fold_change <- function (file){
  # Data import
  dat <- read_tsv(file = file, skip = 2, col_names = F, col_types = cols()) %>% 
    select(1:9) %>%
    t() %>%
    as.data.frame
  
  # Change riBAQ to numeric
  dat$V2 <- as.numeric(as.character(dat$V2))
  
  # Set new names
  colnames(dat) <- c("method", "riBAQ") # set column names
  dat[1]<- c("Cent.", "Cent.", "Cent.", "SEC", "SEC", "SEC", "PAP", "PAP", "PAP")
  
  # Calculate mean
  dat_fold <- dat %>% 
    group_by(method) %>%
    summarise(mean = mean(riBAQ, na.rm = T))
  
  
  
  # Calculate fold change
  print(paste("The fold difference between Cent. vs PAP is:", foldchange(num = dat_fold[1,2], denom = dat_fold[2,2])))
  print(paste("The fold difference between PAP vs SEC is:", foldchange(num = dat_fold[2,2], denom = dat_fold[3,2])))
  print(paste("The fold difference between Cent. vs SEC is:", foldchange(num = dat_fold[1,2], denom = dat_fold[3,2])))
  
  # Give summary statistics
  print("Summary statistics")
  return(print(dat_fold))
}

# Check for outliers using the above 1.5 IQR method
outliers <- function(data, column, groupnr, n = 3){
  groupnr <- (nrow(data)/n)
  j <- 1
  for (i in 1:groupnr) {
    start <- j
    j <- j + n
    if(!is.null(boxplot.stats(data$column[start:n*i])$out)){
      print(paste("Outlier in ", data[[j-1, 1]], "for ", column))
    }
    else{
      print(paste("No outliers in ", data[[j-1, 1]], "for ", column))
    }
  }
}

# Check normality with shapiro wilks
normality <- function(dat, column, n = 3){
  # Figure out how many groups there are
  groupnr <- (nrow(dat)/n)
  
  # Some variables
  j <- 1
  print(dat[1:3, column])
  
  # A for loop going trough the different groups
  for (i in 1:groupnr) {
    # Some more variables
    start <- j
    j <- j + n
    
    # Actual test
    print(paste("Normality: ", dat[[j-1, 1]], " in ", column, ":", sep = ""))
    print(shapiro.test(pull(dat[start:(n*i), column])))
  }
}