######################## MS data processing ###############################
# This file opens the MS (MaxQuant) data files, filter out contaminants, and calculates riBAQ values, and writes
# this to a new file.

## Load packages
library(tidyverse)


############ Import data
## Read data
ms_df <- read_tsv("Data/1 - Optimization study (2016)/Raw/MaxQuant/proteinGroups.txt", col_types = cols(Reverse = col_character()))

## Filter data
ms_df_filt <- 
  ms_df %>% 
  filter(is.na(`Potential contaminant`)) %>% # Contaminants 
  filter(is.na(Reverse)) %>% # Rev hits
  filter(is.na(`Only identified by site`)) # Only identified by site


########## Calculate riBAQ
## Selects IBAQ columns
rIBAQ <- select(ms_df_filt, contains("IBAQ"))


## New matrix for riBAQ
mat_rIBAQ <- matrix(nrow = nrow(rIBAQ[1]))



## Calculate rIBAQ loop - Will take some time
for(i in ncol(rIBAQ):1) {
  ## Creates vector to store rIBAQ
  rIBAQ_col <- c()
  
  # Get sum of column
  sum <- sum(rIBAQ[[i]], na.rm = T)
  
  for (j in 1:nrow(rIBAQ[i])) ## row loop
  {
    ## IBAQ value
    IBAQ <- rIBAQ[[j,i]]
    
    ## Check if it returns NaN
    if(is.na(IBAQ/sum))
    {
      rIBAQ_col[j] <- 0
    }
    else
    {
      ## Store IBAQ into vector
      rIBAQ_col[j] <- IBAQ/sum
    }
  }
  ## Append vector to ms_df_filt
  mat_rIBAQ <- cbind(rIBAQ_col, mat_rIBAQ)
}

## Change column names
for (i in 1:ncol(rIBAQ)) {
  colnames(mat_rIBAQ)[i] <- paste("rIBAQ_", colnames(rIBAQ[i]), sep = "")  
}

## Combine dfs
final_matrix <- cbind(ms_df_filt, mat_rIBAQ)

## Write df
write_tsv(final_matrix, "data/1 - Optimization study (2016)/Raw/proteingroups_processed.txt")

## Close stuff
rm(final_matrix, mat_rIBAQ, ms_df, ms_df_filt, rIBAQ, i, IBAQ, j, rIBAQ_col, sum)




