########################  3NTA data import and tidy ###############################
# This file imports and tidy NTA data. To be used for figure 1 and section about particle size and concentration.

## Load packages
if (!require("tidyverse")) install.packages("tidyverse")

### Import raw data ###
# Read data
NTAdata <- read_csv("Data/1 - Optimization study (2016)/NTA/NTA_size+Concentration.csv", col_names = F) %>%
  t %>%
  as.data.frame

# Add new column names
colnames(NTAdata) <- c("data", "method", "rep_1", "rep_2", "rep_3")

### Convert rows to numeric ###
NTAdata <- toNumeric(dat = NTAdata, columNr = 3)


### Rotate data into tidy form ###
# Pivot rep data into rows
NTAdata <- NTAdata %>%
  pivot_longer(-c(data, method), 
               values_to = "value") %>%
  arrange(data)

# Spread data
NTAdata <- spread(NTAdata, data, value)


### Change names and final tidy ###
# Change name column to remove rep
NTAdata$name <- str_replace(NTAdata$name, "rep_", "")

# Change name colum to numeric
NTAdata$name <- as.numeric(NTAdata$name)

# New column names
colnames(NTAdata) <- c("method", "control", "NTA_concentration", "NTA_mean", "NTA_mode")

# Sets method as factor
NTAdata$method <- as.factor(NTAdata$method)

# arranges methods
NTAdata <- NTAdata %>%
  arrange(name = factor(method, levels=c("PPP", "Cent.", "SEC", "PAP"))) 
