######################## Image processing ###############################
# This file creates some of the images used in the article. They are created from raw images.

# Section 1 - Custom functions, packages, and other dependencies -----------------------------------------------------------------------------------
################################ 1.1 - Packages #################################### 
### Check that packages are installed ###
if (!require("tidyverse")) install.packages("tidyverse")
if (!require("magick")) install.packages("magick")

# Section 1 - TEM  -----------------------------------------------------------------------------------
### Figure 2D -  and TEM ###
# Crop image and add scale bar
TEMimgCrop("Figures/1 - Optimization study (2016)/Raw/TEM/Cent (1).png", "Cent (1).png")
TEMimgCrop("Figures/1 - Optimization study (2016)/Raw/TEM/Cent (2).png", "Cent (2).png")
TEMimgCrop("Figures/1 - Optimization study (2016)/Raw/TEM/SEC (1).png", "SEC (1).png")
TEMimgCrop("Figures/1 - Optimization study (2016)/Raw/TEM/SEC (2).png", "SEC (2).png")
TEMimgCrop("Figures/1 - Optimization study (2016)/Raw/TEM/Vn96(1).png", "Vn96(1).png")
TEMimgCrop("Figures/1 - Optimization study (2016)/Raw/TEM/Vn96(2).png", "Vn96(2).png")

# TEM Images combined
cent_TEM <- combineTEM("Figures/1 - Optimization study (2016)/Edited/TEM/Cropped/Cent (1).png", "Figures/1 - Optimization study (2016)/Edited/TEM/Cropped/Cent (2).png", "Cent.")
SEC_TEM <- combineTEM("Figures/1 - Optimization study (2016)/Edited/TEM/Cropped/SEC (1).png", "Figures/1 - Optimization study (2016)/Edited/TEM/Cropped/SEC (2).png", "SEC")
PAP_TEM <- combineTEM("Figures/1 - Optimization study (2016)/Edited/TEM/Cropped/Vn96(1).png", "Figures/1 - Optimization study (2016)/Edited/TEM/Cropped/Vn96(2).png", "PAP")

# Combined TEM
image_write(image_append(c(cent_TEM, SEC_TEM, PAP_TEM)), path = "Figures/1 - Optimization study (2016)/Edited/TEM/Combined/combined.png", format = "png")



# Section 2 - Western blots  -----------------------------------------------------------------------------------
################################ 2.1 - CD9 #################################### 
### Original ###
# Open WB and crop
img <- image_read("Figures/1 - Optimization study (2016)/Raw/Western blot/CD9.png")
imgRot <- image_rotate(img, -3)
imgCrop <- image_crop(imgRot, "1200x350+238+1240")
imgCrop

# Extract lanes
laneLadder <-  image_crop(imgCrop, "115x350")
laneLadder

laneSECPAP <- image_crop(imgCrop, "230x350+763")
laneSECPAP

laneEmpty <- image_crop(imgCrop, "115x350+360")
laneEmpty

lanePos <- image_crop(imgCrop, "130x350+242")
lanePos

# Combine lanes
imgCombined <- c(laneLadder, lanePos, laneSECPAP)
imgCombinedFinal <- image_append(image_scale(imgCombined, "x200"))
imgCombinedFinal

# Draw seperating lines
imgLines <- image_draw(imgCombinedFinal)

abline(v = 65, col = 'black', lwd = '3', lty = "dotted")
abline(v = 135, col = 'black', lwd = '3', lty = "dotted")
abline(v = 205, col = 'black', lwd = '3', lty = "dotted")
abline(v = 275, col = 'black', lwd = '3', lty = "dotted")
dev.off() # Turn of drawing function

imgRezise <- image_border(imgLines, "white", "45x50x")

# Annotate  
imgAnnotate <- imgRezise %>%
  image_annotate("     MW \n standard\ ", size = 16.5, color = "black", location = "+40+5") %>%
  image_annotate("Positive \n control\ ", size = 16.5, color = "black", location = "+113+5") %>%
  image_annotate("SEC", size = 16.5, color = "black", location = "+195+12") %>%
  image_annotate("PAP", size = 16.5, color = "black", location = "+270+12") %>%
  image_annotate("kDa", size = 15, color = "black", location = "+8+40") %>%
  image_annotate("37", size = 13, color = "black", location = "+20+60") %>%
  image_annotate("25", size = 13, color = "black", location = "+20+120") %>%
  image_annotate("20", size = 13, color = "black", location = "+20+145") %>%
  image_annotate("15", size = 13, color = "black", location = "+20+195") %>%
  image_annotate("10", size = 13, color = "black", location = "+20+220")
imgAnnotate

### Extra blot for cenrifugation ###
# Open WB and crop
img2 <- image_read("Figures/1 - Optimization study (2016)/Raw/Western blot/CD9_for_centrifugation.png")
img2

# Extract lanes
imgCrop2 <- image_crop(img2, "800x780+600+260")
imgCrop2

imgCrop2cent <- image_crop(img2, "500x780+1680+260")
imgCrop2cent

# Combine lanes
imgCombine2 <- c(imgCrop2, imgCrop2cent)
imgCombinedFinal2 <- image_append(image_scale(imgCombine2, "x200"))
imgCombinedFinal2

img2Scale <- image_scale(imgCombinedFinal2, "240")

# Draw seperating lines
imgLines2 <- image_draw(img2Scale)
imgLines2
abline(v = 62, col = 'black', lwd = '3', lty = "dotted")
abline(v = 146, col = 'black', lwd = '3', lty = "dotted")
dev.off() # Turn of drawing function

img2Rezise <- image_border(imgLines2, "white", "40x40x")

# Annotate
img2Annotate <- img2Rezise %>%
  image_annotate("     MW \n standard\ ", size = 14.5, color = "black", location = "+38+5") %>%
  image_annotate("Positive \n control\ ", size = 14.5, color = "black", location = "+115+5") %>%
  image_annotate("Cent.", size = 14.5, color = "black", location = "+214+10") %>%
  image_annotate("kDa", size = 14, color = "black", location = "+8+33") %>%
  image_annotate("37", size = 12, color = "black", location = "+20+54") %>%
  image_annotate("25", size = 12, color = "black", location = "+20+120") %>%
  image_annotate("20", size = 12, color = "black", location = "+20+143")
img2Annotate


### Combine WB ###
# Combine
imgCombined3 <- c(imgAnnotate, img2Annotate)
imgCombinedFinal3 <- image_append((imgCombined3))
imgCombinedFinal3

imgCropFinal <- image_crop(imgCombinedFinal3, "640x240+0+0")
imgCropFinal

# Save
image_write(imgCropFinal, path = "Figures/1 - Optimization study (2016)/Edited/Western blot/CD9_WB.png", format = "png")



################################ 2.2 - ApoB #################################### 
# Open WB and crop
img3 <- image_read("Figures/1 - Optimization study (2016)/Raw/Western blot/ApoB.tif")
img3

imgCrop3 <- image_crop(img3, "1300x400+550+800")
imgCrop3

# Extract lanes
laneLadder3 <-  image_crop(imgCrop3, "110x550+1125+0")
laneLadder3

lanePPP3 <- image_crop(imgCrop3, "130x550+13")
lanePPP3

laneCent3 <- image_crop(imgCrop3, "130x550+747")
laneCent3

laneSEC3 <- image_crop(imgCrop3, "130x550+495")
laneSEC3

lanePAP3 <- image_crop(imgCrop3, "130x550+255")
lanePAP3

# Combine lanes
imgCombine3 <- c(laneLadder3, lanePPP3, laneCent3, laneSEC3, lanePAP3)
imgCombinedFinal3 <- image_append(image_scale(imgCombine3, "x200"))
imgCombinedFinal3

# Draw stuff
imgLines3 <- image_draw(imgCombinedFinal3)

abline(v = 55, col = 'black', lwd = '3', lty = "dotted")
abline(v = 120, col = 'black', lwd = '3', lty = "dotted")
abline(v = 185, col = 'black', lwd = '3', lty = "dotted")
abline(v = 250, col = 'black', lwd = '3', lty = "dotted")
dev.off()

imgRezise3 <- image_border(imgLines3, "white", "45x50x")

# Annotate
imgAnnotate3 <- imgRezise3 %>%
  image_annotate("     MW \n standard\ ", size = 16.5, color = "black", location = "+32+5") %>%
  image_annotate("Positive \n control\ ", size = 16.5, color = "black", location = "+105+5") %>%
  image_annotate("Cent.", size = 16.5, color = "black", location = "+177+12") %>%
  image_annotate("SEC", size = 16.5, color = "black", location = "+247+12") %>%
  image_annotate("PAP", size = 16.5, color = "black", location = "+315+12") %>%
  image_annotate("kDa", size = 15, color = "black", location = "+8+40") %>%
  image_annotate("ApoB", size = 13, color = "black", location = "+8+90") %>%
  image_annotate("(>250nm)", size = 9, color = "black", location = "+8+105") %>%
  image_annotate("250", size = 13, color = "black", location = "+15+130") %>%
  image_annotate("150", size = 13, color = "black", location = "+15+180") %>%
  image_annotate("100", size = 13, color = "black", location = "+15+220")
imgAnnotate3

# Save
image_write(imgAnnotate3, path = "Figures/1 - Optimization study (2016)/Edited/Western blot/apoB_WB.png",width = 1000, format = "png")

