########################  Size distribution ###############################
# This file calculates the size distribution to make figure 1s.


## Library
if (!require("tidyverse")) install.packages("tidyverse")


## Load data
NTA_size_dist <- read_tsv("Data/1 - Optimization study (2016)/NTA/Particle size distribution.csv")

NTA_size_dist_piv <- NTA_size_dist %>%
  pivot_longer(-c(particle_size_nm), 
               values_to = "value")


######### Figures
## Cent 
fig_cent <- NTA_size_dist_piv %>% 
  filter(name %in% c("Cent_1", "Cent_2", "Cent_3"))


fig_cent <- fig_cent %>%
  ggplot(aes(x=particle_size_nm, y=value, group=name, color = name)) +
  geom_line() +
  ylab("Particle size") +
  theme_pubr(base_size = 20) +
  theme(legend.position = c(0.8, 0.9), plot.title = element_text(size=30)) +
  xlim(0, 600) +
  labs(title = "Centrifugation", y ="Particles/mL", x = "Particle size (nm)", x = "") +
  scale_color_discrete(name = "Sample ID",labels =c("Control 1", "Control 2", "Control 3"))

fig_cent

## SEC 
fig_SEC <- NTA_size_dist_piv %>% 
  filter(name %in% c("SEC_1", "SEC_2", "SEC_3"))

fig_SEC <- fig_SEC %>%
  ggplot(aes(x=particle_size_nm, y=value, group=name, color = name)) +
  geom_line() +
  ylab("Particle size") +
  theme_pubr(base_size = 20) +
  theme(legend.position = c(0.8, 0.9), plot.title = element_text(size=30)) +
  xlim(0, 600) +
  labs(title = "SEC", y ="Particles/mL", x = "Particle size (nm)", x = "") +
  scale_color_discrete(name = "Sample ID",labels =c("Control 1", "Control 2", "Control 3"))
fig_SEC

## PAP 
fig_PAP <- NTA_size_dist_piv %>% 
  filter(name %in% c("PAP_1", "PAP_2", "PAP_3"))

fig_PAP <- fig_PAP %>%
  ggplot(aes(x=particle_size_nm, y=value, group=name, color = name)) +
  geom_line() +
  ylab("Particle size") +
  theme_pubr(base_size = 20) +
  theme(legend.position = c(0.8, 0.9), plot.title = element_text(size=30)) +
  xlim(0, 600) +
  labs(title = "PAP", y ="Particles/mL", x = "Particle size (nm)", x = "") +
  scale_color_discrete(name = "Sample ID",labels =c("Control 1", "Control 2", "Control 3"))


fig_PAP 

## Means
fig_mean <- NTA_size_dist_piv %>% 
  filter(name %in% c("Cent_mean", "SEC_mean", "PAP_mean"))


fig_mean <- fig_mean %>%
  ggplot(aes(x=particle_size_nm, y=value, group=name, color = name)) +
  geom_line() +
  ylab("Particle size") +
  theme_pubr(base_size = 20) +
  theme(legend.position = c(0.8, 0.9), plot.title = element_text(size=30)) +
  xlim(0, 600) +
  labs(title = "Isolation methods - Mean", x = "Particle size (nm)",y ="Particles/mL", x = "") +
  scale_color_discrete(name = "Sample ID",labels =c("Cent.", "PAP", "SEC"))

fig_mean


## Combine figures
figure_1s <- plot_grid(fig_cent, fig_SEC, fig_PAP, fig_mean, labels = "AUTO", label_size = 40, hjust = -0.1, vjust = 1.3, cols = 2, rows = 3, rel_heights = c(4,4,1))

figure_1s <- ggdraw(figure_1s) +  draw_label("Figure S1.", x = 0.01, y = 0.08, hjust = 0, vjust = 0, fontface = "bold", size = 16) + draw_label("                  Nanoparticle tracking analysis size distribution, showing the disribution of particles over the measured size range. (A) High-speed centrifugation (B) Size Exclusion Chromatography (SEC), \n(C) Peptide affinity precipitation (PAP), (D) Means of biological replicates for high speed centrifugation, SEC, and PAP.", x = 0.01, y = 0.05, hjust = 0, vjust = 0, fontface = "plain", size = 16, lineheight = 1.2)



## Save figure

ggsave(figure_1s, filename = "Figures/1 - Optimization study (2016)/Publication/figure_S1.png", width = 20, height = 10)
 
